/*
 * This file and its contents are licensed under the Timescale License.
 * Please see the included NOTICE for copyright information and
 * LICENSE-TIMESCALE for a copy of the license.
 */
#pragma once

#include <postgres.h>

extern void hypercore_set_am(const RangeVar *rv, const char *amname);
extern void hypercore_set_compressed_autovacuum_reloption(Chunk *chunk, bool enabled);
